@@ -17,12 +17,14 @@ app = import_string(settings.IDP_USER_APP['FAUST_APP_PATH'])
     "email": "",
     "app_specific_configs": {
         "app_identifier": {
-            "Servicer": {
-                "app_config": {"vehicle_ids": [1, 2]},
-                "permission_restrictions": {
-                    "synchronizeDoD": False
+            "tenant": {
+                "Servicer": {
+                    "app_config": {"vehicle_ids": [1, 2]},
+                    "permission_restrictions": {
+                        "synchronizeDoD": False
+                    }
                 }
-            }
+            },
         }
     }
 }
@@ -38,7 +40,9 @@ class UserRecord(faust.Record):
     app_specific_configs: dict = None
 
 
-user_updates = app.topic(settings.IDP_USER_APP['USER_UPDATES_TOPIC_NAME'], value_type=UserRecord)
+USER_UPDATES_TOPIC_NAME = f"{settings.APP_ENV}_user_updates"
+
+user_updates = app.topic(USER_UPDATES_TOPIC_NAME, value_type=UserRecord)
 
 
 @sync_to_async
